==> flutter_wechat-0.0.7.tar.gz: example/android/app/src/main/java/com/weidao/app/wxapi/WXEntryActivity.java <==
package com.weidao.app.wxapi;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.widget.Toast;

import com.tencent.mm.opensdk.modelbase.BaseReq;
import com.tencent.mm.opensdk.modelbase.BaseResp;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.IWXAPIEventHandler;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;

/**
 * Created by xukankan on 2018/4/12.
 */

public class WXEntryActivity extends Activity implements IWXAPIEventHandler {


    private IWXAPI api;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        api = WXAPIFactory.createWXAPI(this, "wxb25d3dec3db1affc", false);
        onNewIntent(getIntent());
        finish();
    }

    @Override
    public void onReq(BaseReq baseReq) {

    }

    @Override
    public void onResp(BaseResp baseResp) {
        String toastString = "";
        switch (baseResp.errCode) {
            case 0:
                toastString = "分享成功";
                break;
            case -1:
                toastString = "一般错误";
                break;
            case -2:
                toastString = "分享取消";
                break;
            case -3:
                toastString = "发送失败";
                break;
            case -4:
                toastString = "认证拒绝";
                break;
            case -5:
                toastString = "分享禁用";
                break;
        }
        Toast.makeText(this, toastString, Toast.LENGTH_SHORT).show();
    }


    protected void onNewIntent(Intent intent) {
        api.handleIntent(intent, this);
    }


}

==> flutter_wechat-0.0.9.tar.gz: example/android/app/src/main/java/com/weidao/app/wxapi/WXEntryActivity.java <==
package com.weidao.app.wxapi;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.widget.Toast;

import com.github.xu.flutterwechat.FlutterWechatPlugin;
import com.tencent.mm.opensdk.modelbase.BaseReq;
import com.tencent.mm.opensdk.modelbase.BaseResp;
import com.tencent.mm.opensdk.modelmsg.SendAuth;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.IWXAPIEventHandler;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;

/**
 * Created by xukankan on 2018/4/12.
 */

public class WXEntryActivity extends Activity implements IWXAPIEventHandler {


    private IWXAPI api;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        api = WXAPIFactory.createWXAPI(this, "wxb25d3dec3db1affc", false);
        onNewIntent(getIntent());
        finish();
    }

    @Override
    public void onReq(BaseReq baseReq) {

    }

    @Override
    public void onResp(BaseResp baseResp) {
        String toastString = "";
        switch (baseResp.errCode) {
            case 0:
                toastString = "操作成功";
                if (baseResp instanceof SendAuth.Resp) {
                    SendAuth.Resp newResp = (SendAuth.Resp) baseResp;
                    //获取微信传回的code
                    String code = newResp.code;
                    FlutterWechatPlugin.setCode(code);
                }
                break;
            case -1:
                toastString = "一般错误";
                break;
            case -2:
                toastString = "取消操作";
                break;
            case -3:
                toastString = "发送失败";
                break;
            case -4:
                toastString = "认证拒绝";
                break;
            case -5:
                toastString = "帐号禁用";
                break;
        }
        Toast.makeText(this, toastString, Toast.LENGTH_SHORT).show();
    }


    protected void onNewIntent(Intent intent) {
        api.handleIntent(intent, this);
    }


}
